@@ -346,7 +346,7 @@ void labeltext(int keypressed, char *clientdata)
 	 topobject->parts++;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-         topobject->valid = False;
+	 invalidate_netlist(topobject);
 #endif
 
       }
@@ -400,7 +400,7 @@ void labeltext(int keypressed, char *clientdata)
 	 eventmode = NORMAL_MODE;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-	 if (curlabel->pin != False) topobject->valid = False;
+	 if (curlabel->pin != False) invalidate_netlist(topobject);
 #endif
       }
 
@@ -419,12 +419,12 @@ void labeltext(int keypressed, char *clientdata)
 	    if ((findlabelcopy(curlabel, labelbuf) == NULL)
 			&& (findlabelcopy(curlabel, curlabel->string) == NULL)) {
 	       changeotherpins(curlabel, labelbuf);
-	       if (topobject->schemtype == SCHEMATIC)
+	       if (topobject->schemtype == PRIMARY || topobject->schemtype == SECONDARY)
 	          Wprintf("Changed corresponding pin in associated symbol");
 	       else
 	          Wprintf("Changed corresponding pin in associated schematic");
 	       incr_changes(topobject->symschem);
-	       topobject->symschem->valid = False;
+	       invalidate_netlist(topobject->symschem);
 	    }
 	 }
 #endif
@@ -553,7 +553,6 @@ void labeltext(int keypressed, char *clientdata)
 	    strcpy(newpart->data.string, clientdata);
 	    ops = match_param(topobject, clientdata);
 	    if (ops == NULL) errcond = True;
-	    else if (ops->type != XC_STRING) errcond = True;
 	    break;
       }
       if (errcond == True) {
@@ -681,7 +680,7 @@ void rejustify(short mode)
       undrawtext(curlabel);
       jsave = curlabel->justify;
       curlabel->justify = transjust[mode] |
-		(curlabel->justify & (FLIPINV | PINVISIBLE));
+		(curlabel->justify & NONJUSTFIELD);
       if (jsave != curlabel->justify) changed = True;
       redrawtext(curlabel);
       UDrawTLine(curlabel);
@@ -696,7 +695,7 @@ void rejustify(short mode)
             jsave = curlabel->justify;
 	    undrawtext(curlabel);
       	    curlabel->justify = transjust[mode] |
-		(curlabel->justify & (FLIPINV | PINVISIBLE));
+		(curlabel->justify & NONJUSTFIELD);
             if (jsave != curlabel->justify) changed = True;
 	    redrawtext(curlabel);
 	 }
@@ -708,7 +707,6 @@ void rejustify(short mode)
    else if (changed) {
       pwriteback(areastruct.topinstance);
       incr_changes(topobject);
-
    }
 }
 
@@ -1723,7 +1721,7 @@ void wirebutton(XButtonEvent *event)
 	 topobject->parts++;
 	 incr_changes(topobject);
 #ifdef SCHEMA
-	 if (!nonnetwork(newwire)) topobject->valid = False;
+	 if (!nonnetwork(newwire)) invalidate_netlist(topobject);
 #endif
       }
       UDrawPolygon(newwire);
