@@ -73,7 +73,7 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Text Up", "Text Down", "Text Split", 
    "Text Home", "Text End", "Return Char", "Parameter",
    "Parameterize Point", "Break at Point", "Delete Point", "Insert Point",
-   "Next Point", "Attach", "Next Library", "Library Directory",
+   "Append Point", "Next Point", "Attach", "Next Library", "Library Directory",
    "Library Move", "Library Copy", "Library Edit", "Library Delete",
    "Library Duplicate", "Library Hide", "Library Virtual Copy",
    "Page Directory", "Library Pop", "Virtual Copy",
@@ -649,10 +649,14 @@ void default_keybindings()
    add_binding(XK_G, XCF_Pin_Global);
    add_binding(XK_I, XCF_Info_Label);
    add_binding(ALT | XK_w, XCF_Connectivity);
-   add_binding(ALT | XK_d, XCF_Sim);
-   add_binding(ALT | XK_a, XCF_SPICE);
-   add_binding(ALT | XK_f, XCF_SPICEflat);
-   add_binding(ALT | XK_p, XCF_PCB);
+
+/* These are for test purposes only.  Menu selection is	*/
+/* preferred.						*/
+
+/* add_binding(ALT | XK_d, XCF_Sim);		*/
+/* add_binding(ALT | XK_a, XCF_SPICE);		*/
+/* add_binding(ALT | XK_f, XCF_SPICEflat);	*/
+/* add_binding(ALT | XK_p, XCF_PCB);		*/
 #endif
 
 }
