@@ -10,11 +10,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -473,7 +468,6 @@ void composepagelib(short mode)
       (*drawbox)->width = 1.0;
       (*drawbox)->number = 4;
       (*drawbox)->points = (pointlist) malloc(4 * sizeof(XPoint));
-      (*drawbox)->num_params = 0;
       (*drawbox)->passed = NULL;
       pointptr = (*drawbox)->points;
       pointptr->x = (i % gxsize) * xdel + margin;
@@ -498,7 +492,6 @@ void composepagelib(short mode)
 	 (*pagelabel)->color = DEFAULTCOLOR;
 	 (*pagelabel)->scale = 0.75;
 	 (*pagelabel)->string->data.font = fval;
-         (*pagelabel)->num_params = 0;
          (*pagelabel)->passed = NULL;
 	 strptr = makesegment(&((*pagelabel)->string), NULL);
 	 strptr->type = TEXT_STRING;
@@ -656,9 +649,9 @@ void composelib(short mode)
 
    reset(libpage, NORMAL);
 
-   /* Return if library defines no objects */
+   /* Return if library defines no objects or virtual instances */
 
-   if (xobjs.userlibs[mode - LIBRARY].number == 0) return;
+   if (xobjs.userlibs[mode - LIBRARY].instlist == NULL) return;
 
    /* Find the Helvetica font for use in labeling the objects */
 
@@ -807,7 +800,7 @@ void catvirtualcopy()
 	  + areastruct.selects; newselect++) {
       libobj = SELTOOBJINST(newselect);
 
-      if (libobj->thisobject->num_params == 0) {
+      if (libobj->thisobject->params == NULL) {
 	 Wprintf("Virtual copy allowed only on objects with paramters.");
 	 /* (because currently there's no way to adjust rotation/scale	*/
 	 /* of a non-parameterized instance from inside the library,	*/
@@ -1148,6 +1141,7 @@ void copycat()
    short *newselect;
    objectptr *newobj, *curlib, oldobj;
    objinstptr libobj;
+   oparamptr ops, newops;
    int i, libnum = USERLIB - LIBRARY ;
 
    for (newselect = areastruct.selectlist; newselect < areastruct.selectlist
@@ -1184,24 +1178,24 @@ void copycat()
       (*newobj)->symschem = NULL;
 
       /* Copy the parameter structure */
-      (*newobj)->num_params = oldobj->num_params;
-      (*newobj)->params = (oparamptr *)malloc(oldobj->num_params *
-		sizeof(oparamptr));
-      for (i = 0; i < oldobj->num_params; i++) {
-	 (*newobj)->params[i] = (oparamptr) malloc(sizeof(oparam));
-	 (*newobj)->params[i]->type = oldobj->params[i]->type;
-	 switch (oldobj->params[i]->type) {
+      (*newobj)->params = NULL;
+      for (ops = oldobj->params; ops != NULL; ops = ops->next) {
+	 newops = (oparamptr)malloc(sizeof(oparam));
+	 newops->next = (*newobj)->params;
+	 (*newobj)->params = newops;
+	 newops->type = ops->type;
+	 switch (ops->type) {
 	    case XC_INT:
-	       (*newobj)->params[i]->parameter.ivalue =
-			oldobj->params[i]->parameter.ivalue;
+	       newops->parameter.ivalue = ops->parameter.ivalue;
 	       break;
 	    case XC_FLOAT:
-	       (*newobj)->params[i]->parameter.fvalue =
-			oldobj->params[i]->parameter.fvalue;
+	       newops->parameter.fvalue = ops->parameter.fvalue;
 	       break;
 	    case XC_STRING:
-	       (*newobj)->params[i]->parameter.string =
-			stringcopy(oldobj->params[i]->parameter.string);
+	       newops->parameter.string = stringcopy(ops->parameter.string);
+	       break;
+	    case XC_EXPR:
+	       newops->parameter.expr = strdup(ops->parameter.expr);
 	       break;
 	 }
       }
@@ -1232,7 +1226,6 @@ void copycat()
 	       (*npath)->parts = 0;
 	       (*npath)->plist = (genericptr *)malloc(cpath->parts *
 			sizeof(genericptr));
-               (*npath)->num_params = 0;
                (*npath)->passed = NULL;
 	       for (gpart = cpath->plist; gpart < cpath->plist + cpath->parts;
 			gpart++) {
@@ -1296,7 +1289,6 @@ void copycat()
 	       (*nlabel)->scale = clabel->scale;
 	       (*nlabel)->justify = clabel->justify;
 	       (*nlabel)->string = stringcopy(clabel->string);
-	       (*nlabel)->num_params = 0;
 	       (*nlabel)->passed = NULL;
 #ifdef SCHEMA
 	       (*nlabel)->pin = clabel->pin;
@@ -1314,7 +1306,6 @@ void copycat()
 	       (*ninst)->position.y = cinst->position.y;
 	       (*ninst)->scale = cinst->scale;
 	       (*ninst)->thisobject = cinst->thisobject;
-	       (*ninst)->num_params = 0;
 	       (*ninst)->passed = NULL;
 
 	       /* Library instance's parameter list is always default (null) */
