@@ -6,17 +6,19 @@
 /* from tclxcircuit.c */
 
 #ifdef TCL_WRAPPER
-
 extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
 extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
-extern objectptr NameToObject(char *, objinstptr *, Boolean);
-
+extern Tcl_Obj *evaluate_raw(oparamptr);
+extern char *TCL_to_PS(char *);
 #endif
 
+extern char *evaluate_expr(oparamptr);
+
 /* from elements.c: */
 
+extern void copyalleparams(genericptr, genericptr);
 extern void copyparams(objinstptr, objinstptr);
 extern void objectdefaults(objinstptr, objectptr, int, int);
 extern void labeldefaults(labelptr, u_char, int, int);
@@ -86,6 +88,7 @@ extern void panrefresh(u_int, XButtonEvent *);
 extern void centerpan(xcWidget, caddr_t, caddr_t);
 extern void checkwarp(XPoint *);
 extern int checkcycle(short, short);
+extern void copyvirtual();
 extern void nextpolycycle(polyptr, short);
 extern void nextsplinecycle(splineptr, short);
 extern void nextarccycle(arcptr, short);
@@ -167,7 +170,7 @@ extern int lookdirectory(char *);
 
 /* from files.c: */
 
-extern void ridnewline(char *);
+extern char *ridnewline(char *);
 extern void free_single(genericptr *);
 extern void reset(objectptr, short);
 extern void pagereset(short);
@@ -179,9 +182,10 @@ extern short objcompare(objectptr, objectptr);
 extern float getpsscale(float, short);
 extern void dostcount(FILE *, short *, short);
 extern short printparams(FILE *, objinstptr, short);
+extern void printobjectparams(FILE *, objectptr);
 extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
 extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
-extern void varpcheck(FILE *, short, objectptr, int, int, short *, genericptr, u_char);
+extern void varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
 extern void getfile(xcWidget, pointertype, caddr_t);
 extern Boolean nextfilename();
 extern void loadfontlib();
@@ -195,6 +199,7 @@ extern void startloadfile();
 extern void importfile();
 extern void loadfile(short);
 extern void readlabel(objectptr, char *, stringpart **);
+extern void readparams(objectptr, objinstptr, objectptr, char *);
 extern u_char *find_match(u_char *);
 extern char *advancetoken(char *);
 extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
@@ -202,10 +207,11 @@ extern char *varscan(objectptr, char *, short *, genericptr, u_char);
 extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern objinstptr addtoinstlist(int, objectptr, Boolean);
 extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int);
-extern void setfile(xcWidget, xcWidget, caddr_t);
 #ifdef TCL_WRAPPER
+void setfile(char *, int);
 extern xcTimeOutProc savetemp(caddr_t);
 #else
+extern void setfile(xcWidget, xcWidget, caddr_t);
 extern xcTimeOutProc savetemp(caddr_t, xcIntervalId *);
 #endif
 extern void savelibpopup(xcWidget, pointertype, caddr_t);
@@ -218,8 +224,10 @@ extern Boolean xc_tilde_expand(char *);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
 extern void writelabelsegs(FILE *, short *, stringpart *);
-extern void printobjects(FILE *, objectptr, float, float, float, short, short,
-                         objectptr **, short *, int);
+extern void printobjects(FILE *, objectptr, objectptr **, short *, int);
+extern void printrefobjects(FILE *, objectptr, objectptr **, short *);
+extern void printpageobject(FILE *, objectptr, short, short);
+
 
 /* from fontfile.c: */
 
@@ -295,8 +303,8 @@ extern void UDrawCircle(XPoint *, u_char);
 extern void UDrawX(labelptr);
 #ifdef SCHEMA
 extern void UDrawXDown(labelptr);
-extern int  toplevelwidth(objinstptr);
-extern int  toplevelheight(objinstptr);
+extern int  toplevelwidth(objinstptr, short *);
+extern int  toplevelheight(objinstptr, short *);
 extern void extendschembbox(objinstptr, XPoint *, XPoint *);
 #endif
 extern void pinadjust(short, short *, short *, short);
@@ -313,6 +321,7 @@ extern void UDrawPolygon(polyptr);
 extern void UDrawArc(arcptr);
 extern void UDrawPath(pathptr);
 extern void UDrawObject(objinstptr, short, int, pushlistptr *);
+extern void TopDoLatex();
 
 /* from help.c: */
 
@@ -348,6 +357,7 @@ extern short findhelvetica();
 extern void catreturn();
 extern int pageposition(short, XButtonEvent *, int);
 extern short pagelinks();
+extern short *pagetotals(int, short);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
 extern void pagecatbutton(XButtonEvent *);
@@ -407,7 +417,9 @@ extern void makenewencodingbutton(char *, char);
 extern void togglefontmark(int);
 #ifndef TCL_WRAPPER
 extern void toggleexcl(xcWidget, menuptr, int);
+extern void promptparam(xcWidget, caddr_t, caddr_t);
 #endif
+extern void stringparam(xcWidget, caddr_t, caddr_t);
 extern void toggle(xcWidget, Boolean *, caddr_t);
 extern void setcolorscheme(Boolean);
 extern void inversecolor(xcWidget, Boolean *, caddr_t);
@@ -441,13 +453,11 @@ extern void setfontmarks(short, short);
 extern void startparam(xcWidget, pointertype, caddr_t);
 extern void startunparam(xcWidget, pointertype, caddr_t);
 extern void setdefaultfontmarks();
-extern void dopinvisible(xcWidget, labelptr);
-extern void doflipflip(xcWidget, labelptr);
+extern void setjustbit(xcWidget, pointertype, caddr_t);
+extern void setpinjustbit(xcWidget, pointertype, caddr_t);
 extern void setjust(xcWidget, pointertype, labelptr, short);
 extern void setvjust(xcWidget, pointertype, caddr_t);
 extern void sethjust(xcWidget, pointertype, caddr_t);
-extern void setflipinv(xcWidget, pointertype, caddr_t);
-extern void setpinvisible(xcWidget, pointertype, caddr_t);
 extern void boxedit(xcWidget, pointertype, caddr_t);
 extern void locloadfont(xcWidget, char *);
 extern void addnewfont(xcWidget, caddr_t, caddr_t);
@@ -464,14 +474,15 @@ extern void border_popup(xcWidget, caddr_t, caddr_t);
 extern void color_popup(xcWidget, caddr_t, caddr_t);
 extern void fill_popup(xcWidget, caddr_t, caddr_t);
 extern void param_popup(xcWidget, caddr_t, caddr_t);
-extern void dospecial(void);
+extern Boolean dospecial(void);
 
 /* from netlist.c: */
 
 #ifdef SCHEMA
-extern void createnets();
+extern void invalidate_netlist(objectptr);
+extern int updatenets(objinstptr);
+extern void createnets(objinstptr);
 extern void destroynets();
-extern void gennet(char *, char *);
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
 extern void gennetlist(objectptr, objinstptr);
@@ -509,37 +520,51 @@ extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
 extern void writeglobals(objectptr, FILE *);
 extern void writehierarchy(objectptr, CalllistPtr, FILE *);
 extern void writenet(objectptr, char *, char *);
-extern void writepcb(objectptr, CalllistPtr, char *, char *);
-extern void outputpcb(objectptr, FILE *);
-extern void freepcb();
+extern void writepcb(struct Ptab **, objectptr, CalllistPtr, char *, char *);
+extern void outputpcb(struct Ptab *, FILE *);
+extern void freepcb(struct Ptab *);
 extern void freenets(objectptr);
 extern void freetemplabels(objectptr);
 extern void freeglobals();
-extern int cleartraversed(objectptr, int);
+extern int cleartraversed(objectptr);
 extern int checkvalid(objectptr);
 extern void clearpins(objectptr);
 #endif
 
 /* from parameter.c: */ 
 
+extern char *find_indirect_param(objinstptr, char *);
+extern oparamptr match_param(objectptr, char *);
+extern oparamptr match_instance_param(objinstptr, char *);
+extern oparamptr find_param(objinstptr, char *);
+extern int get_num_params(objectptr);
+extern void free_object_param(objectptr, oparamptr);
+extern void free_instance_param(objinstptr, oparamptr);
+extern void free_element_param(genericptr, eparamptr);
+
+extern oparamptr make_new_parameter(char *);
+extern eparamptr make_new_eparam(char *);
+
+extern void makeexprparam(objectptr, char *, char *, int);
+extern void makefloatparam(objectptr, char *, float);
+extern void makestringparam(objectptr, char *, stringpart *);
 extern void indicateparams(genericptr);
-extern void makenumericalp(genericptr *, u_int);
-extern void unmakenumericalp(genericptr *, u_int);
+extern void makenumericalp(genericptr *, u_int, char *);
 extern void noparmstrcpy(u_char *, u_char *);
 extern void insertparam();
-extern void makeparam(labelptr);
-extern void initinst(objectptr, objectptr, short);
-extern void searchinst(objectptr, objectptr, short);
-extern void initallinstances(objectptr, int);
+extern void makeparam(labelptr, char *);
+extern void searchinst(objectptr, objectptr, char *);
 extern stringpart *searchparam(stringpart *);
 extern void unmakeparam(labelptr, stringpart *);
+extern void unmakenumericalp(genericptr *, u_int);         
 extern void unparameterize(int);
-extern void parameterize(int);
+extern void parameterize(int, char *);
 extern genericptr findparam(objectptr, void *, u_char);
 extern Boolean paramcross(objectptr, labelptr);
 extern oparamptr parampos(objectptr, labelptr, char *, short *, short *);
 extern int opsubstitute(objectptr, objinstptr);
 extern int psubstitute(objinstptr);
+extern oparamptr copyparameter(oparamptr);
 extern void pwriteback(objinstptr);
 extern short paramlen(u_char *);
 extern int natstrlen(u_char *);
@@ -594,7 +619,8 @@ extern int reset_gs();
 
 /* from schema.c: */
 
-extern void callgennet(xcWidget, pointertype, caddr_t);
+extern objectptr NameToObject(char *, objinstptr *, Boolean);
+extern void callwritenet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
 extern void startconnect(xcWidget, caddr_t, caddr_t);
 extern int connectivity(xcWidget, caddr_t, caddr_t);
@@ -603,7 +629,8 @@ extern void pinconvert(labelptr, pointertype);
 extern void dopintype(xcWidget, pointertype, caddr_t);
 extern void setsymschem();
 extern int findpageobj(objectptr);
-extern int findsubschems(int, objectptr, int);
+extern void collectsubschems(int);
+extern int findsubschems(int, objectptr, int, short *);
 extern void copypinlabel(labelptr);
 extern int checkschem(objectptr, char *);
 extern int checksym(objectptr, char *);
